datastructuretools.TypedTuple
=============================

.. abjad-lineage:: abjad.tools.datastructuretools.TypedTuple.TypedTuple

.. autoclass:: abjad.tools.datastructuretools.TypedTuple.TypedTuple

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.count
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.custom_identifier
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.index
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.item_class
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.__add__
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.__contains__
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.__eq__
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.__format__
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.__getitem__
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.__getslice__
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.__hash__
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.__iter__
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.__len__
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.__makenew__
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.__mul__
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.__ne__
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.__repr__
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple.__rmul__

Bases
-----

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.item_class
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.custom_identifier
   :noindex:

Methods
-------

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.count
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.index
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.__add__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.__contains__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.__format__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.__getitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.__getslice__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.__hash__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.__iter__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.__len__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.__makenew__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.__mul__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.__repr__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedTuple.TypedTuple.__rmul__
   :noindex:
